obj/main/SITL/rx/rx.o: src/main/rx/rx.c src/main/platform.h \
 src/main/target/common_pre.h \
 src/platform/SIMULATOR/include/platform/platform.h \
 src/platform/SIMULATOR/target/SITL/target.h src/main/common/utils.h \
 src/main/target/common_post.h src/main/build/version.h \
 src/main/target/serial_post.h src/main/target/common_defaults_post.h \
 src/main/build/build_config.h src/main/build/debug.h \
 src/main/common/maths.h src/main/common/filter.h \
 src/main/config/config.h src/main/pg/pg.h src/main/config/config_reset.h \
 src/main/config/feature.h src/main/drivers/adc.h \
 src/main/drivers/io_types.h src/main/drivers/time.h \
 src/main/common/time.h src/main/drivers/rx/rx_pwm.h \
 src/main/fc/rc_controls.h src/main/common/axis.h src/main/fc/rc_modes.h \
 src/main/fc/runtime_config.h src/main/fc/tasks.h \
 src/main/scheduler/scheduler.h src/main/pg/scheduler.h \
 src/main/flight/failsafe.h src/main/io/serial.h \
 src/main/drivers/serial.h src/main/drivers/io.h \
 src/main/drivers/resource.h src/main/drivers/io_def.h \
 src/platform/SIMULATOR/io_def_generated.h \
 src/main/drivers/serial_resource.h src/main/pg/pg_ids.h src/main/pg/rx.h \
 src/main/rx/rx.h src/main/rx/pwm.h src/main/rx/fport.h \
 src/main/rx/sbus.h src/main/rx/spektrum.h src/main/rx/srxl2.h \
 src/main/rx/sumd.h src/main/rx/sumh.h src/main/rx/msp.h \
 src/main/rx/xbus.h src/main/rx/ibus.h src/main/rx/jetiexbus.h \
 src/main/rx/crsf.h src/main/rx/crsf_protocol.h src/main/rx/ghst.h \
 src/main/rx/ghst_protocol.h src/main/rx/rx_spi.h src/main/drivers/exti.h \
 src/main/pg/rx_spi.h src/main/rx/targetcustomserial.h \
 src/main/rx/msp_override.h
src/main/platform.h:
src/main/target/common_pre.h:
src/platform/SIMULATOR/include/platform/platform.h:
src/platform/SIMULATOR/target/SITL/target.h:
src/main/common/utils.h:
src/main/target/common_post.h:
src/main/build/version.h:
src/main/target/serial_post.h:
src/main/target/common_defaults_post.h:
src/main/build/build_config.h:
src/main/build/debug.h:
src/main/common/maths.h:
src/main/common/filter.h:
src/main/config/config.h:
src/main/pg/pg.h:
src/main/config/config_reset.h:
src/main/config/feature.h:
src/main/drivers/adc.h:
src/main/drivers/io_types.h:
src/main/drivers/time.h:
src/main/common/time.h:
src/main/drivers/rx/rx_pwm.h:
src/main/fc/rc_controls.h:
src/main/common/axis.h:
src/main/fc/rc_modes.h:
src/main/fc/runtime_config.h:
src/main/fc/tasks.h:
src/main/scheduler/scheduler.h:
src/main/pg/scheduler.h:
src/main/flight/failsafe.h:
src/main/io/serial.h:
src/main/drivers/serial.h:
src/main/drivers/io.h:
src/main/drivers/resource.h:
src/main/drivers/io_def.h:
src/platform/SIMULATOR/io_def_generated.h:
src/main/drivers/serial_resource.h:
src/main/pg/pg_ids.h:
src/main/pg/rx.h:
src/main/rx/rx.h:
src/main/rx/pwm.h:
src/main/rx/fport.h:
src/main/rx/sbus.h:
src/main/rx/spektrum.h:
src/main/rx/srxl2.h:
src/main/rx/sumd.h:
src/main/rx/sumh.h:
src/main/rx/msp.h:
src/main/rx/xbus.h:
src/main/rx/ibus.h:
src/main/rx/jetiexbus.h:
src/main/rx/crsf.h:
src/main/rx/crsf_protocol.h:
src/main/rx/ghst.h:
src/main/rx/ghst_protocol.h:
src/main/rx/rx_spi.h:
src/main/drivers/exti.h:
src/main/pg/rx_spi.h:
src/main/rx/targetcustomserial.h:
src/main/rx/msp_override.h:
