obj/main/SITL/drivers/sound_beeper.o: src/main/drivers/sound_beeper.c \
 src/main/platform.h src/main/target/common_pre.h \
 src/platform/SIMULATOR/include/platform/platform.h \
 src/platform/SIMULATOR/target/SITL/target.h src/main/common/utils.h \
 src/main/target/common_post.h src/main/build/version.h \
 src/main/target/serial_post.h src/main/target/common_defaults_post.h \
 src/main/drivers/io.h src/main/drivers/resource.h \
 src/main/drivers/io_types.h src/main/drivers/io_def.h \
 src/platform/SIMULATOR/io_def_generated.h src/main/drivers/pwm_output.h \
 src/main/common/time.h src/main/pg/pg.h src/main/build/build_config.h \
 src/main/drivers/dma.h src/platform/SIMULATOR/include/platform/dma.h \
 src/main/drivers/motor_types.h src/main/drivers/timer.h \
 src/platform/SIMULATOR/timer_def.h src/main/pg/timerio.h \
 src/main/pg/pg_ids.h src/main/drivers/dma_reqmap.h src/main/pg/motor.h \
 src/main/pg/beeper_dev.h src/main/drivers/sound_beeper.h
src/main/platform.h:
src/main/target/common_pre.h:
src/platform/SIMULATOR/include/platform/platform.h:
src/platform/SIMULATOR/target/SITL/target.h:
src/main/common/utils.h:
src/main/target/common_post.h:
src/main/build/version.h:
src/main/target/serial_post.h:
src/main/target/common_defaults_post.h:
src/main/drivers/io.h:
src/main/drivers/resource.h:
src/main/drivers/io_types.h:
src/main/drivers/io_def.h:
src/platform/SIMULATOR/io_def_generated.h:
src/main/drivers/pwm_output.h:
src/main/common/time.h:
src/main/pg/pg.h:
src/main/build/build_config.h:
src/main/drivers/dma.h:
src/platform/SIMULATOR/include/platform/dma.h:
src/main/drivers/motor_types.h:
src/main/drivers/timer.h:
src/platform/SIMULATOR/timer_def.h:
src/main/pg/timerio.h:
src/main/pg/pg_ids.h:
src/main/drivers/dma_reqmap.h:
src/main/pg/motor.h:
src/main/pg/beeper_dev.h:
src/main/drivers/sound_beeper.h:
