obj/main/SITL/drivers/serial.o: src/main/drivers/serial.c \
 src/main/platform.h src/main/target/common_pre.h \
 src/platform/SIMULATOR/include/platform/platform.h \
 src/platform/SIMULATOR/target/SITL/target.h src/main/common/utils.h \
 src/main/target/common_post.h src/main/build/version.h \
 src/main/target/serial_post.h src/main/target/common_defaults_post.h \
 src/main/io/serial.h src/main/pg/pg.h src/main/build/build_config.h \
 src/main/drivers/serial.h src/main/drivers/io.h \
 src/main/drivers/resource.h src/main/drivers/io_types.h \
 src/main/drivers/io_def.h src/platform/SIMULATOR/io_def_generated.h \
 src/main/drivers/serial_resource.h
src/main/platform.h:
src/main/target/common_pre.h:
src/platform/SIMULATOR/include/platform/platform.h:
src/platform/SIMULATOR/target/SITL/target.h:
src/main/common/utils.h:
src/main/target/common_post.h:
src/main/build/version.h:
src/main/target/serial_post.h:
src/main/target/common_defaults_post.h:
src/main/io/serial.h:
src/main/pg/pg.h:
src/main/build/build_config.h:
src/main/drivers/serial.h:
src/main/drivers/io.h:
src/main/drivers/resource.h:
src/main/drivers/io_types.h:
src/main/drivers/io_def.h:
src/platform/SIMULATOR/io_def_generated.h:
src/main/drivers/serial_resource.h:
