obj/main/SITL/rx/fport.o: src/main/rx/fport.c src/main/platform.h \
 src/main/target/common_pre.h \
 src/platform/SIMULATOR/include/platform/platform.h \
 src/platform/SIMULATOR/target/SITL/target.h src/main/common/utils.h \
 src/main/target/common_post.h src/main/build/version.h \
 src/main/target/serial_post.h src/main/target/common_defaults_post.h
src/main/platform.h:
src/main/target/common_pre.h:
src/platform/SIMULATOR/include/platform/platform.h:
src/platform/SIMULATOR/target/SITL/target.h:
src/main/common/utils.h:
src/main/target/common_post.h:
src/main/build/version.h:
src/main/target/serial_post.h:
src/main/target/common_defaults_post.h:
