obj/main/SITL/flight/position.o: src/main/flight/position.c \
 src/main/platform.h src/main/target/common_pre.h \
 src/platform/SIMULATOR/include/platform/platform.h \
 src/platform/SIMULATOR/target/SITL/target.h src/main/common/utils.h \
 src/main/target/common_post.h src/main/build/version.h \
 src/main/target/serial_post.h src/main/target/common_defaults_post.h \
 src/main/build/debug.h src/main/common/maths.h src/main/common/filter.h \
 src/main/fc/runtime_config.h src/main/flight/position.h \
 src/main/common/time.h src/main/pg/pg.h src/main/build/build_config.h \
 src/main/flight/imu.h src/main/common/axis.h src/main/common/vector.h \
 src/main/flight/pid.h src/main/common/chirp.h src/main/common/pwl.h \
 src/main/io/gps.h src/main/io/serial.h src/main/drivers/serial.h \
 src/main/drivers/io.h src/main/drivers/resource.h \
 src/main/drivers/io_types.h src/main/drivers/io_def.h \
 src/platform/SIMULATOR/io_def_generated.h \
 src/main/drivers/serial_resource.h src/main/pg/gps.h \
 src/main/scheduler/scheduler.h src/main/config/config.h \
 src/main/pg/scheduler.h src/main/sensors/sensors.h \
 src/main/sensors/barometer.h src/main/drivers/barometer/barometer.h \
 src/main/drivers/bus.h src/main/drivers/bus_i2c.h src/main/drivers/dma.h \
 src/platform/SIMULATOR/include/platform/dma.h src/main/drivers/exti.h \
 src/main/pg/pg_ids.h
src/main/platform.h:
src/main/target/common_pre.h:
src/platform/SIMULATOR/include/platform/platform.h:
src/platform/SIMULATOR/target/SITL/target.h:
src/main/common/utils.h:
src/main/target/common_post.h:
src/main/build/version.h:
src/main/target/serial_post.h:
src/main/target/common_defaults_post.h:
src/main/build/debug.h:
src/main/common/maths.h:
src/main/common/filter.h:
src/main/fc/runtime_config.h:
src/main/flight/position.h:
src/main/common/time.h:
src/main/pg/pg.h:
src/main/build/build_config.h:
src/main/flight/imu.h:
src/main/common/axis.h:
src/main/common/vector.h:
src/main/flight/pid.h:
src/main/common/chirp.h:
src/main/common/pwl.h:
src/main/io/gps.h:
src/main/io/serial.h:
src/main/drivers/serial.h:
src/main/drivers/io.h:
src/main/drivers/resource.h:
src/main/drivers/io_types.h:
src/main/drivers/io_def.h:
src/platform/SIMULATOR/io_def_generated.h:
src/main/drivers/serial_resource.h:
src/main/pg/gps.h:
src/main/scheduler/scheduler.h:
src/main/config/config.h:
src/main/pg/scheduler.h:
src/main/sensors/sensors.h:
src/main/sensors/barometer.h:
src/main/drivers/barometer/barometer.h:
src/main/drivers/bus.h:
src/main/drivers/bus_i2c.h:
src/main/drivers/dma.h:
src/platform/SIMULATOR/include/platform/dma.h:
src/main/drivers/exti.h:
src/main/pg/pg_ids.h:
