obj/main/SITL/blackbox/blackbox.o: src/main/blackbox/blackbox.c \
 src/main/platform.h src/main/target/common_pre.h \
 src/platform/SIMULATOR/include/platform/platform.h \
 src/platform/SIMULATOR/target/SITL/target.h src/main/common/utils.h \
 src/main/target/common_post.h src/main/build/version.h \
 src/main/target/serial_post.h src/main/target/common_defaults_post.h \
 src/main/blackbox/blackbox.h src/main/build/build_config.h \
 src/main/common/time.h src/main/pg/pg.h \
 src/main/blackbox/blackbox_encoding.h \
 src/main/blackbox/blackbox_fielddefs.h src/main/blackbox/blackbox_io.h \
 src/main/build/debug.h src/main/common/axis.h src/main/common/encoding.h \
 src/main/common/maths.h src/main/config/config.h \
 src/main/config/feature.h src/main/cli/settings.h \
 src/main/drivers/compass/compass.h src/main/common/sensor_alignment.h \
 src/main/common/vector.h src/main/drivers/bus.h \
 src/main/drivers/bus_i2c.h src/main/drivers/io_types.h \
 src/main/drivers/dma.h src/main/drivers/resource.h \
 src/platform/SIMULATOR/include/platform/dma.h src/main/drivers/sensor.h \
 src/main/drivers/exti.h src/main/drivers/time.h src/main/fc/board_info.h \
 src/main/fc/controlrate_profile.h src/main/fc/parameter_names.h \
 src/main/fc/rc.h src/main/fc/rc_controls.h src/main/common/filter.h \
 src/main/fc/rc_modes.h src/main/fc/runtime_config.h \
 src/main/flight/failsafe.h src/main/flight/gps_rescue.h \
 src/main/flight/gps_rescue_multirotor.h src/main/pg/gps_rescue.h \
 src/main/pg/gps_rescue_multirotor.h src/main/pg/gps_rescue_wing.h \
 src/main/flight/gps_rescue_wing.h src/main/flight/mixer.h \
 src/main/drivers/motor.h src/main/pg/motor.h src/main/drivers/io.h \
 src/main/drivers/io_def.h src/platform/SIMULATOR/io_def_generated.h \
 src/main/drivers/motor_types.h src/main/flight/pid.h \
 src/main/common/chirp.h src/main/common/pwl.h src/main/flight/position.h \
 src/main/flight/rpm_filter.h src/main/pg/rpm_filter.h \
 src/main/flight/servos.h src/main/drivers/pwm_output.h \
 src/main/drivers/timer.h src/platform/SIMULATOR/timer_def.h \
 src/main/pg/timerio.h src/main/pg/pg_ids.h src/main/drivers/dma_reqmap.h \
 src/main/flight/imu.h src/main/io/beeper.h src/main/io/gps.h \
 src/main/io/serial.h src/main/drivers/serial.h \
 src/main/drivers/serial_resource.h src/main/pg/gps.h \
 src/main/pg/alt_hold.h src/main/pg/alt_hold_multirotor.h \
 src/main/pg/alt_hold_wing.h src/main/pg/autopilot.h \
 src/main/pg/autopilot_multirotor.h src/main/pg/autopilot_wing.h \
 src/main/pg/pilot.h src/main/pg/pos_hold.h \
 src/main/pg/pos_hold_multirotor.h src/main/pg/pos_hold_wing.h \
 src/main/pg/rx.h src/main/rx/rx.h src/main/sensors/acceleration.h \
 src/main/drivers/accgyro/accgyro.h \
 src/main/drivers/accgyro/accgyro_mpu.h src/main/sensors/sensors.h \
 src/main/sensors/barometer.h src/main/drivers/barometer/barometer.h \
 src/main/sensors/battery.h src/main/sensors/current.h \
 src/main/sensors/current_ids.h src/main/sensors/voltage.h \
 src/main/sensors/voltage_ids.h src/main/sensors/compass.h \
 src/main/sensors/gyro.h src/main/sensors/gyro_init.h \
 src/main/pg/gyrodev.h src/main/sensors/rangefinder.h \
 src/main/drivers/rangefinder/rangefinder.h
src/main/platform.h:
src/main/target/common_pre.h:
src/platform/SIMULATOR/include/platform/platform.h:
src/platform/SIMULATOR/target/SITL/target.h:
src/main/common/utils.h:
src/main/target/common_post.h:
src/main/build/version.h:
src/main/target/serial_post.h:
src/main/target/common_defaults_post.h:
src/main/blackbox/blackbox.h:
src/main/build/build_config.h:
src/main/common/time.h:
src/main/pg/pg.h:
src/main/blackbox/blackbox_encoding.h:
src/main/blackbox/blackbox_fielddefs.h:
src/main/blackbox/blackbox_io.h:
src/main/build/debug.h:
src/main/common/axis.h:
src/main/common/encoding.h:
src/main/common/maths.h:
src/main/config/config.h:
src/main/config/feature.h:
src/main/cli/settings.h:
src/main/drivers/compass/compass.h:
src/main/common/sensor_alignment.h:
src/main/common/vector.h:
src/main/drivers/bus.h:
src/main/drivers/bus_i2c.h:
src/main/drivers/io_types.h:
src/main/drivers/dma.h:
src/main/drivers/resource.h:
src/platform/SIMULATOR/include/platform/dma.h:
src/main/drivers/sensor.h:
src/main/drivers/exti.h:
src/main/drivers/time.h:
src/main/fc/board_info.h:
src/main/fc/controlrate_profile.h:
src/main/fc/parameter_names.h:
src/main/fc/rc.h:
src/main/fc/rc_controls.h:
src/main/common/filter.h:
src/main/fc/rc_modes.h:
src/main/fc/runtime_config.h:
src/main/flight/failsafe.h:
src/main/flight/gps_rescue.h:
src/main/flight/gps_rescue_multirotor.h:
src/main/pg/gps_rescue.h:
src/main/pg/gps_rescue_multirotor.h:
src/main/pg/gps_rescue_wing.h:
src/main/flight/gps_rescue_wing.h:
src/main/flight/mixer.h:
src/main/drivers/motor.h:
src/main/pg/motor.h:
src/main/drivers/io.h:
src/main/drivers/io_def.h:
src/platform/SIMULATOR/io_def_generated.h:
src/main/drivers/motor_types.h:
src/main/flight/pid.h:
src/main/common/chirp.h:
src/main/common/pwl.h:
src/main/flight/position.h:
src/main/flight/rpm_filter.h:
src/main/pg/rpm_filter.h:
src/main/flight/servos.h:
src/main/drivers/pwm_output.h:
src/main/drivers/timer.h:
src/platform/SIMULATOR/timer_def.h:
src/main/pg/timerio.h:
src/main/pg/pg_ids.h:
src/main/drivers/dma_reqmap.h:
src/main/flight/imu.h:
src/main/io/beeper.h:
src/main/io/gps.h:
src/main/io/serial.h:
src/main/drivers/serial.h:
src/main/drivers/serial_resource.h:
src/main/pg/gps.h:
src/main/pg/alt_hold.h:
src/main/pg/alt_hold_multirotor.h:
src/main/pg/alt_hold_wing.h:
src/main/pg/autopilot.h:
src/main/pg/autopilot_multirotor.h:
src/main/pg/autopilot_wing.h:
src/main/pg/pilot.h:
src/main/pg/pos_hold.h:
src/main/pg/pos_hold_multirotor.h:
src/main/pg/pos_hold_wing.h:
src/main/pg/rx.h:
src/main/rx/rx.h:
src/main/sensors/acceleration.h:
src/main/drivers/accgyro/accgyro.h:
src/main/drivers/accgyro/accgyro_mpu.h:
src/main/sensors/sensors.h:
src/main/sensors/barometer.h:
src/main/drivers/barometer/barometer.h:
src/main/sensors/battery.h:
src/main/sensors/current.h:
src/main/sensors/current_ids.h:
src/main/sensors/voltage.h:
src/main/sensors/voltage_ids.h:
src/main/sensors/compass.h:
src/main/sensors/gyro.h:
src/main/sensors/gyro_init.h:
src/main/pg/gyrodev.h:
src/main/sensors/rangefinder.h:
src/main/drivers/rangefinder/rangefinder.h:
