obj/main/SITL/sensors/barometer.o: src/main/sensors/barometer.c \
 src/main/platform.h src/main/target/common_pre.h \
 src/platform/SIMULATOR/include/platform/platform.h \
 src/platform/SIMULATOR/target/SITL/target.h src/main/common/utils.h \
 src/main/target/common_post.h src/main/build/version.h \
 src/main/target/serial_post.h src/main/target/common_defaults_post.h \
 src/main/build/debug.h src/main/common/maths.h src/main/common/filter.h \
 src/main/pg/pg.h src/main/build/build_config.h src/main/pg/pg_ids.h \
 src/main/drivers/barometer/barometer.h src/main/drivers/bus.h \
 src/main/drivers/bus_i2c.h src/main/drivers/io_types.h \
 src/main/drivers/dma.h src/main/drivers/resource.h \
 src/platform/SIMULATOR/include/platform/dma.h src/main/drivers/exti.h \
 src/main/drivers/barometer/barometer_bmp085.h \
 src/main/drivers/barometer/barometer_bmp280.h \
 src/main/drivers/barometer/barometer_bmp388.h \
 src/main/drivers/barometer/barometer_dps310.h \
 src/main/drivers/barometer/barometer_qmp6988.h \
 src/main/drivers/barometer/barometer_virtual.h \
 src/main/drivers/barometer/barometer_ms5611.h \
 src/main/drivers/barometer/barometer_lps.h \
 src/main/drivers/barometer/barometer_2smpb_02b.h \
 src/main/drivers/barometer/barometer_lps22df.h \
 src/main/drivers/bus_i2c_busdev.h src/main/drivers/bus_spi.h \
 src/main/drivers/io.h src/main/drivers/io_def.h \
 src/platform/SIMULATOR/io_def_generated.h src/main/drivers/time.h \
 src/main/common/time.h src/main/fc/runtime_config.h \
 src/main/sensors/sensors.h src/main/scheduler/scheduler.h \
 src/main/config/config.h src/main/pg/scheduler.h \
 src/main/sensors/barometer.h
src/main/platform.h:
src/main/target/common_pre.h:
src/platform/SIMULATOR/include/platform/platform.h:
src/platform/SIMULATOR/target/SITL/target.h:
src/main/common/utils.h:
src/main/target/common_post.h:
src/main/build/version.h:
src/main/target/serial_post.h:
src/main/target/common_defaults_post.h:
src/main/build/debug.h:
src/main/common/maths.h:
src/main/common/filter.h:
src/main/pg/pg.h:
src/main/build/build_config.h:
src/main/pg/pg_ids.h:
src/main/drivers/barometer/barometer.h:
src/main/drivers/bus.h:
src/main/drivers/bus_i2c.h:
src/main/drivers/io_types.h:
src/main/drivers/dma.h:
src/main/drivers/resource.h:
src/platform/SIMULATOR/include/platform/dma.h:
src/main/drivers/exti.h:
src/main/drivers/barometer/barometer_bmp085.h:
src/main/drivers/barometer/barometer_bmp280.h:
src/main/drivers/barometer/barometer_bmp388.h:
src/main/drivers/barometer/barometer_dps310.h:
src/main/drivers/barometer/barometer_qmp6988.h:
src/main/drivers/barometer/barometer_virtual.h:
src/main/drivers/barometer/barometer_ms5611.h:
src/main/drivers/barometer/barometer_lps.h:
src/main/drivers/barometer/barometer_2smpb_02b.h:
src/main/drivers/barometer/barometer_lps22df.h:
src/main/drivers/bus_i2c_busdev.h:
src/main/drivers/bus_spi.h:
src/main/drivers/io.h:
src/main/drivers/io_def.h:
src/platform/SIMULATOR/io_def_generated.h:
src/main/drivers/time.h:
src/main/common/time.h:
src/main/fc/runtime_config.h:
src/main/sensors/sensors.h:
src/main/scheduler/scheduler.h:
src/main/config/config.h:
src/main/pg/scheduler.h:
src/main/sensors/barometer.h:
