obj/main/SITL/fc/init.o: src/main/fc/init.c src/main/platform.h \
 src/main/target/common_pre.h \
 src/platform/SIMULATOR/include/platform/platform.h \
 src/platform/SIMULATOR/target/SITL/target.h src/main/common/utils.h \
 src/main/target/common_post.h src/main/build/version.h \
 src/main/target/serial_post.h src/main/target/common_defaults_post.h \
 src/main/blackbox/blackbox.h src/main/build/build_config.h \
 src/main/common/time.h src/main/pg/pg.h src/main/build/debug.h \
 src/main/build/debug_pin.h src/main/drivers/io_types.h \
 src/main/cms/cms.h src/main/drivers/display.h src/main/cms/cms_types.h \
 src/main/common/axis.h src/main/common/color.h src/main/common/maths.h \
 src/main/common/printf_serial.h src/main/config/config.h \
 src/main/config/config_eeprom.h src/main/config/feature.h \
 src/main/drivers/accgyro/accgyro.h src/main/common/sensor_alignment.h \
 src/main/common/vector.h src/main/drivers/accgyro/accgyro_mpu.h \
 src/main/drivers/bus.h src/main/drivers/bus_i2c.h src/main/drivers/dma.h \
 src/main/drivers/resource.h \
 src/platform/SIMULATOR/include/platform/dma.h src/main/drivers/exti.h \
 src/main/drivers/sensor.h src/main/drivers/adc.h src/main/drivers/time.h \
 src/main/drivers/bus_octospi.h src/main/drivers/bus_quadspi.h \
 src/main/pg/pg_ids.h src/main/drivers/bus_spi.h \
 src/main/drivers/buttons.h src/main/drivers/camera_control_impl.h \
 src/main/drivers/pwm_output.h src/main/drivers/motor_types.h \
 src/main/drivers/timer.h src/platform/SIMULATOR/timer_def.h \
 src/main/pg/timerio.h src/main/drivers/dma_reqmap.h \
 src/main/drivers/io.h src/main/drivers/io_def.h \
 src/platform/SIMULATOR/io_def_generated.h src/main/pg/motor.h \
 src/main/drivers/compass/compass.h src/main/drivers/dshot.h \
 src/main/drivers/dshot_bitbang.h src/main/drivers/flash/flash.h \
 src/main/pg/flash.h src/main/drivers/inverter.h \
 src/main/drivers/serial.h src/main/drivers/serial_resource.h \
 src/main/io/serial.h src/main/drivers/light_led.h src/main/drivers/mco.h \
 src/main/pg/mco.h src/main/drivers/nvic.h src/main/drivers/persistent.h \
 src/main/drivers/pin_pull_up_down.h src/main/drivers/rx/rx_pwm.h \
 src/main/drivers/serial_softserial.h src/main/drivers/serial_uart.h \
 src/main/drivers/sdcard.h src/main/pg/sdcard.h src/main/drivers/sdio.h \
 src/main/drivers/sound_beeper.h src/main/drivers/system.h \
 src/main/drivers/transponder_ir.h src/main/drivers/usb_io.h \
 src/main/drivers/vtx_common.h src/main/common/streambuf.h \
 src/main/drivers/vtx_rtc6705.h src/main/pg/vtx_io.h \
 src/main/drivers/vtx_table.h src/main/fc/board_info.h \
 src/main/fc/dispatch.h src/main/fc/gps_lap_timer.h src/main/io/gps.h \
 src/main/pg/gps.h src/main/pg/gps_lap_timer.h src/main/fc/init.h \
 src/main/fc/rc_controls.h src/main/common/filter.h \
 src/main/fc/runtime_config.h src/main/fc/stats.h src/main/fc/tasks.h \
 src/main/scheduler/scheduler.h src/main/pg/scheduler.h \
 src/main/flight/alt_hold.h src/main/flight/alt_hold_multirotor.h \
 src/main/pg/alt_hold.h src/main/pg/alt_hold_multirotor.h \
 src/main/pg/alt_hold_wing.h src/main/flight/alt_hold_wing.h \
 src/main/flight/autopilot.h src/main/flight/autopilot_multirotor.h \
 src/main/flight/autopilot_wing.h src/main/flight/failsafe.h \
 src/main/flight/imu.h src/main/flight/mixer.h src/main/drivers/motor.h \
 src/main/flight/gps_rescue.h src/main/flight/gps_rescue_multirotor.h \
 src/main/pg/gps_rescue.h src/main/pg/gps_rescue_multirotor.h \
 src/main/pg/gps_rescue_wing.h src/main/flight/gps_rescue_wing.h \
 src/main/flight/pid.h src/main/common/chirp.h src/main/common/pwl.h \
 src/main/flight/pid_init.h src/main/flight/position.h \
 src/main/flight/pos_hold.h src/main/flight/pos_hold_multirotor.h \
 src/main/flight/pos_hold_wing.h src/main/flight/servos.h \
 src/main/io/asyncfatfs/asyncfatfs.h \
 src/main/io/asyncfatfs/fat_standard.h src/main/io/beeper.h \
 src/main/io/dashboard.h src/main/io/displayport_frsky_osd.h \
 src/main/drivers/osd.h src/main/io/displayport_max7456.h \
 src/main/pg/displayport_profiles.h src/main/io/displayport_msp.h \
 src/main/io/flashfs.h src/main/io/gimbal.h src/main/io/gimbal_control.h \
 src/main/io/ledstrip.h src/main/drivers/light_ws2811strip.h \
 src/main/io/pidaudio.h src/main/io/piniobox.h src/main/pg/piniobox.h \
 src/main/drivers/pinio.h src/main/fc/rc_modes.h \
 src/main/io/rcdevice_cam.h src/main/io/rcdevice.h \
 src/main/io/transponder_ir.h src/main/io/vtx.h src/main/io/vtx_control.h \
 src/main/io/vtx_msp.h src/main/io/vtx_rtc6705.h \
 src/main/io/vtx_smartaudio.h src/main/io/vtx_tramp.h \
 src/main/msc/emfat_file.h src/main/msp/msp.h src/main/msp/msp_serial.h \
 src/main/osd/osd.h src/main/common/unit.h src/main/sensors/esc_sensor.h \
 src/main/pg/adc.h src/main/pg/beeper.h src/main/pg/beeper_dev.h \
 src/main/pg/bus_i2c.h src/main/pg/bus_spi.h src/main/pg/bus_quadspi.h \
 src/main/pg/pinio.h src/main/pg/pin_pull_up_down.h src/main/pg/rx.h \
 src/main/pg/rx_pwm.h src/main/pg/rx_spi.h src/main/pg/vcd.h \
 src/main/rx/rx.h src/main/rx/spektrum.h src/main/sensors/acceleration.h \
 src/main/sensors/sensors.h src/main/sensors/barometer.h \
 src/main/drivers/barometer/barometer.h src/main/sensors/battery.h \
 src/main/sensors/current.h src/main/sensors/current_ids.h \
 src/main/sensors/voltage.h src/main/sensors/voltage_ids.h \
 src/main/sensors/boardalignment.h src/main/sensors/compass.h \
 src/main/sensors/gyro.h src/main/sensors/gyro_init.h \
 src/main/pg/gyrodev.h src/main/sensors/initialisation.h \
 src/main/telemetry/telemetry.h src/main/telemetry/ibus_shared.h
src/main/platform.h:
src/main/target/common_pre.h:
src/platform/SIMULATOR/include/platform/platform.h:
src/platform/SIMULATOR/target/SITL/target.h:
src/main/common/utils.h:
src/main/target/common_post.h:
src/main/build/version.h:
src/main/target/serial_post.h:
src/main/target/common_defaults_post.h:
src/main/blackbox/blackbox.h:
src/main/build/build_config.h:
src/main/common/time.h:
src/main/pg/pg.h:
src/main/build/debug.h:
src/main/build/debug_pin.h:
src/main/drivers/io_types.h:
src/main/cms/cms.h:
src/main/drivers/display.h:
src/main/cms/cms_types.h:
src/main/common/axis.h:
src/main/common/color.h:
src/main/common/maths.h:
src/main/common/printf_serial.h:
src/main/config/config.h:
src/main/config/config_eeprom.h:
src/main/config/feature.h:
src/main/drivers/accgyro/accgyro.h:
src/main/common/sensor_alignment.h:
src/main/common/vector.h:
src/main/drivers/accgyro/accgyro_mpu.h:
src/main/drivers/bus.h:
src/main/drivers/bus_i2c.h:
src/main/drivers/dma.h:
src/main/drivers/resource.h:
src/platform/SIMULATOR/include/platform/dma.h:
src/main/drivers/exti.h:
src/main/drivers/sensor.h:
src/main/drivers/adc.h:
src/main/drivers/time.h:
src/main/drivers/bus_octospi.h:
src/main/drivers/bus_quadspi.h:
src/main/pg/pg_ids.h:
src/main/drivers/bus_spi.h:
src/main/drivers/buttons.h:
src/main/drivers/camera_control_impl.h:
src/main/drivers/pwm_output.h:
src/main/drivers/motor_types.h:
src/main/drivers/timer.h:
src/platform/SIMULATOR/timer_def.h:
src/main/pg/timerio.h:
src/main/drivers/dma_reqmap.h:
src/main/drivers/io.h:
src/main/drivers/io_def.h:
src/platform/SIMULATOR/io_def_generated.h:
src/main/pg/motor.h:
src/main/drivers/compass/compass.h:
src/main/drivers/dshot.h:
src/main/drivers/dshot_bitbang.h:
src/main/drivers/flash/flash.h:
src/main/pg/flash.h:
src/main/drivers/inverter.h:
src/main/drivers/serial.h:
src/main/drivers/serial_resource.h:
src/main/io/serial.h:
src/main/drivers/light_led.h:
src/main/drivers/mco.h:
src/main/pg/mco.h:
src/main/drivers/nvic.h:
src/main/drivers/persistent.h:
src/main/drivers/pin_pull_up_down.h:
src/main/drivers/rx/rx_pwm.h:
src/main/drivers/serial_softserial.h:
src/main/drivers/serial_uart.h:
src/main/drivers/sdcard.h:
src/main/pg/sdcard.h:
src/main/drivers/sdio.h:
src/main/drivers/sound_beeper.h:
src/main/drivers/system.h:
src/main/drivers/transponder_ir.h:
src/main/drivers/usb_io.h:
src/main/drivers/vtx_common.h:
src/main/common/streambuf.h:
src/main/drivers/vtx_rtc6705.h:
src/main/pg/vtx_io.h:
src/main/drivers/vtx_table.h:
src/main/fc/board_info.h:
src/main/fc/dispatch.h:
src/main/fc/gps_lap_timer.h:
src/main/io/gps.h:
src/main/pg/gps.h:
src/main/pg/gps_lap_timer.h:
src/main/fc/init.h:
src/main/fc/rc_controls.h:
src/main/common/filter.h:
src/main/fc/runtime_config.h:
src/main/fc/stats.h:
src/main/fc/tasks.h:
src/main/scheduler/scheduler.h:
src/main/pg/scheduler.h:
src/main/flight/alt_hold.h:
src/main/flight/alt_hold_multirotor.h:
src/main/pg/alt_hold.h:
src/main/pg/alt_hold_multirotor.h:
src/main/pg/alt_hold_wing.h:
src/main/flight/alt_hold_wing.h:
src/main/flight/autopilot.h:
src/main/flight/autopilot_multirotor.h:
src/main/flight/autopilot_wing.h:
src/main/flight/failsafe.h:
src/main/flight/imu.h:
src/main/flight/mixer.h:
src/main/drivers/motor.h:
src/main/flight/gps_rescue.h:
src/main/flight/gps_rescue_multirotor.h:
src/main/pg/gps_rescue.h:
src/main/pg/gps_rescue_multirotor.h:
src/main/pg/gps_rescue_wing.h:
src/main/flight/gps_rescue_wing.h:
src/main/flight/pid.h:
src/main/common/chirp.h:
src/main/common/pwl.h:
src/main/flight/pid_init.h:
src/main/flight/position.h:
src/main/flight/pos_hold.h:
src/main/flight/pos_hold_multirotor.h:
src/main/flight/pos_hold_wing.h:
src/main/flight/servos.h:
src/main/io/asyncfatfs/asyncfatfs.h:
src/main/io/asyncfatfs/fat_standard.h:
src/main/io/beeper.h:
src/main/io/dashboard.h:
src/main/io/displayport_frsky_osd.h:
src/main/drivers/osd.h:
src/main/io/displayport_max7456.h:
src/main/pg/displayport_profiles.h:
src/main/io/displayport_msp.h:
src/main/io/flashfs.h:
src/main/io/gimbal.h:
src/main/io/gimbal_control.h:
src/main/io/ledstrip.h:
src/main/drivers/light_ws2811strip.h:
src/main/io/pidaudio.h:
src/main/io/piniobox.h:
src/main/pg/piniobox.h:
src/main/drivers/pinio.h:
src/main/fc/rc_modes.h:
src/main/io/rcdevice_cam.h:
src/main/io/rcdevice.h:
src/main/io/transponder_ir.h:
src/main/io/vtx.h:
src/main/io/vtx_control.h:
src/main/io/vtx_msp.h:
src/main/io/vtx_rtc6705.h:
src/main/io/vtx_smartaudio.h:
src/main/io/vtx_tramp.h:
src/main/msc/emfat_file.h:
src/main/msp/msp.h:
src/main/msp/msp_serial.h:
src/main/osd/osd.h:
src/main/common/unit.h:
src/main/sensors/esc_sensor.h:
src/main/pg/adc.h:
src/main/pg/beeper.h:
src/main/pg/beeper_dev.h:
src/main/pg/bus_i2c.h:
src/main/pg/bus_spi.h:
src/main/pg/bus_quadspi.h:
src/main/pg/pinio.h:
src/main/pg/pin_pull_up_down.h:
src/main/pg/rx.h:
src/main/pg/rx_pwm.h:
src/main/pg/rx_spi.h:
src/main/pg/vcd.h:
src/main/rx/rx.h:
src/main/rx/spektrum.h:
src/main/sensors/acceleration.h:
src/main/sensors/sensors.h:
src/main/sensors/barometer.h:
src/main/drivers/barometer/barometer.h:
src/main/sensors/battery.h:
src/main/sensors/current.h:
src/main/sensors/current_ids.h:
src/main/sensors/voltage.h:
src/main/sensors/voltage_ids.h:
src/main/sensors/boardalignment.h:
src/main/sensors/compass.h:
src/main/sensors/gyro.h:
src/main/sensors/gyro_init.h:
src/main/pg/gyrodev.h:
src/main/sensors/initialisation.h:
src/main/telemetry/telemetry.h:
src/main/telemetry/ibus_shared.h:
