obj/main/SITL/blackbox/blackbox_io.o: src/main/blackbox/blackbox_io.c \
 src/main/platform.h src/main/target/common_pre.h \
 src/platform/SIMULATOR/include/platform/platform.h \
 src/platform/SIMULATOR/target/SITL/target.h src/main/common/utils.h \
 src/main/target/common_post.h src/main/build/version.h \
 src/main/target/serial_post.h src/main/target/common_defaults_post.h \
 src/main/build/debug.h src/main/blackbox/blackbox.h \
 src/main/build/build_config.h src/main/common/time.h src/main/pg/pg.h \
 src/main/blackbox/blackbox_io.h src/main/common/maths.h \
 src/main/flight/pid.h src/main/common/axis.h src/main/common/chirp.h \
 src/main/common/filter.h src/main/common/pwl.h \
 src/main/io/asyncfatfs/asyncfatfs.h \
 src/main/io/asyncfatfs/fat_standard.h src/main/io/flashfs.h \
 src/main/io/serial.h src/main/drivers/serial.h src/main/drivers/io.h \
 src/main/drivers/resource.h src/main/drivers/io_types.h \
 src/main/drivers/io_def.h src/platform/SIMULATOR/io_def_generated.h \
 src/main/drivers/serial_resource.h src/main/msp/msp_serial.h \
 src/main/drivers/time.h src/main/msp/msp.h src/main/common/streambuf.h \
 src/main/blackbox/blackbox_virtual.h
src/main/platform.h:
src/main/target/common_pre.h:
src/platform/SIMULATOR/include/platform/platform.h:
src/platform/SIMULATOR/target/SITL/target.h:
src/main/common/utils.h:
src/main/target/common_post.h:
src/main/build/version.h:
src/main/target/serial_post.h:
src/main/target/common_defaults_post.h:
src/main/build/debug.h:
src/main/blackbox/blackbox.h:
src/main/build/build_config.h:
src/main/common/time.h:
src/main/pg/pg.h:
src/main/blackbox/blackbox_io.h:
src/main/common/maths.h:
src/main/flight/pid.h:
src/main/common/axis.h:
src/main/common/chirp.h:
src/main/common/filter.h:
src/main/common/pwl.h:
src/main/io/asyncfatfs/asyncfatfs.h:
src/main/io/asyncfatfs/fat_standard.h:
src/main/io/flashfs.h:
src/main/io/serial.h:
src/main/drivers/serial.h:
src/main/drivers/io.h:
src/main/drivers/resource.h:
src/main/drivers/io_types.h:
src/main/drivers/io_def.h:
src/platform/SIMULATOR/io_def_generated.h:
src/main/drivers/serial_resource.h:
src/main/msp/msp_serial.h:
src/main/drivers/time.h:
src/main/msp/msp.h:
src/main/common/streambuf.h:
src/main/blackbox/blackbox_virtual.h:
