obj/main/SITL/sensors/gyro.o: src/main/sensors/gyro.c src/main/platform.h \
 src/main/target/common_pre.h \
 src/platform/SIMULATOR/include/platform/platform.h \
 src/platform/SIMULATOR/target/SITL/target.h src/main/common/utils.h \
 src/main/target/common_post.h src/main/build/version.h \
 src/main/target/serial_post.h src/main/target/common_defaults_post.h \
 src/main/build/debug.h src/main/common/axis.h src/main/common/maths.h \
 src/main/common/filter.h src/main/config/feature.h src/main/pg/pg.h \
 src/main/build/build_config.h src/main/config/simplified_tuning.h \
 src/main/flight/pid.h src/main/common/chirp.h src/main/common/pwl.h \
 src/main/common/time.h src/main/sensors/gyro.h \
 src/main/drivers/accgyro/accgyro.h src/main/common/sensor_alignment.h \
 src/main/common/vector.h src/main/drivers/accgyro/accgyro_mpu.h \
 src/main/drivers/bus.h src/main/drivers/bus_i2c.h \
 src/main/drivers/io_types.h src/main/drivers/dma.h \
 src/main/drivers/resource.h \
 src/platform/SIMULATOR/include/platform/dma.h src/main/drivers/exti.h \
 src/main/drivers/sensor.h src/main/pg/pg_ids.h src/main/pg/gyrodev.h \
 src/main/drivers/bus_spi.h src/main/drivers/io.h \
 src/main/drivers/io_def.h src/platform/SIMULATOR/io_def_generated.h \
 src/main/config/config.h src/main/fc/runtime_config.h \
 src/main/flight/rpm_filter.h src/main/pg/rpm_filter.h \
 src/main/io/beeper.h src/main/io/statusindicator.h \
 src/main/scheduler/scheduler.h src/main/pg/scheduler.h \
 src/main/sensors/boardalignment.h src/main/sensors/gyro_init.h \
 src/main/sensors/gyro_filter_impl.c
src/main/platform.h:
src/main/target/common_pre.h:
src/platform/SIMULATOR/include/platform/platform.h:
src/platform/SIMULATOR/target/SITL/target.h:
src/main/common/utils.h:
src/main/target/common_post.h:
src/main/build/version.h:
src/main/target/serial_post.h:
src/main/target/common_defaults_post.h:
src/main/build/debug.h:
src/main/common/axis.h:
src/main/common/maths.h:
src/main/common/filter.h:
src/main/config/feature.h:
src/main/pg/pg.h:
src/main/build/build_config.h:
src/main/config/simplified_tuning.h:
src/main/flight/pid.h:
src/main/common/chirp.h:
src/main/common/pwl.h:
src/main/common/time.h:
src/main/sensors/gyro.h:
src/main/drivers/accgyro/accgyro.h:
src/main/common/sensor_alignment.h:
src/main/common/vector.h:
src/main/drivers/accgyro/accgyro_mpu.h:
src/main/drivers/bus.h:
src/main/drivers/bus_i2c.h:
src/main/drivers/io_types.h:
src/main/drivers/dma.h:
src/main/drivers/resource.h:
src/platform/SIMULATOR/include/platform/dma.h:
src/main/drivers/exti.h:
src/main/drivers/sensor.h:
src/main/pg/pg_ids.h:
src/main/pg/gyrodev.h:
src/main/drivers/bus_spi.h:
src/main/drivers/io.h:
src/main/drivers/io_def.h:
src/platform/SIMULATOR/io_def_generated.h:
src/main/config/config.h:
src/main/fc/runtime_config.h:
src/main/flight/rpm_filter.h:
src/main/pg/rpm_filter.h:
src/main/io/beeper.h:
src/main/io/statusindicator.h:
src/main/scheduler/scheduler.h:
src/main/pg/scheduler.h:
src/main/sensors/boardalignment.h:
src/main/sensors/gyro_init.h:
src/main/sensors/gyro_filter_impl.c:
